pub fn parse_with_info(
payload: &[u8],
) -> Result<(TextMessage<'_>, ParseInfo), ParseError>Expand description
Decode a text-message payload, also returning option occurrence information for semantic validation.
pub fn parse_with_info(
payload: &[u8],
) -> Result<(TextMessage<'_>, ParseInfo), ParseError>Decode a text-message payload, also returning option occurrence information for semantic validation.