pub fn destination_for(conversation: &ConversationKey) -> DestinationExpand description
Delivery mode of a conversation, used for original sends and for resend responses (which return on the conversation’s mode, not the request’s arrival path).
pub fn destination_for(conversation: &ConversationKey) -> DestinationDelivery mode of a conversation, used for original sends and for resend responses (which return on the conversation’s mode, not the request’s arrival path).