CoalesceRing

Struct CoalesceRing 

pub struct CoalesceRing { /* private fields */ }
Ring of recently transmitted or answered frames, for coalescing resend requests: duplicate requests from multiple group members, and requests for a frame whose original transmission just left this node (a slow serialized link can deliver frames later than the requester’s patience).

Implementations

Source

impl CoalesceRing

pub fn recently_answered( &self, conversation: &ConversationKey, sequence: &MessageSequence, now_ms: u64, window_ms: u64, ) -> bool

True when an equivalent request was answered within window_ms.

pub fn record( &mut self, conversation: ConversationKey, sequence: &MessageSequence, now_ms: u64, )

pub fn record_frame( &mut self, conversation: ConversationKey, message_id: u8, fragment: Option<u8>, now_ms: u64, )

Record one frame by its archive coordinates, refreshing any existing entry for the same frame.