ParseError

Enum ParseError 

pub enum ParseError {
    Core(ParseError),
    InvalidUtf8,
    InvalidPayloadType(u8),
    PayloadTypeNotAllowed {
        payload_type: u8,
        packet_type: PacketType,
    },
    InvalidMessageType(u8),
    InvalidOptionValue,
}
Error returned when parsing or validating text payloads.

Variants



Core(ParseError)

Propagated umsh-core parse error.



InvalidUtf8

A field that must be valid UTF-8 was not valid UTF-8.



InvalidPayloadType(u8)

The leading payload-type byte did not identify a text payload.



PayloadTypeNotAllowed

The payload type is known, but it is invalid for the given packet type.

Fields

payload_type: u8
packet_type: PacketType


InvalidMessageType(u8)

The text-message type byte is not one of the registered values.



InvalidOptionValue

An option payload or fixed-width field had an invalid encoding.