pub fn parse_text_payload(
packet_type: PacketType,
payload: &[u8],
) -> Result<TextMessage<'_>, ParseError>Expand description
Parse a typed text payload in the context of the enclosing packet type.
pub fn parse_text_payload(
packet_type: PacketType,
payload: &[u8],
) -> Result<TextMessage<'_>, ParseError>Parse a typed text payload in the context of the enclosing packet type.