pub struct RefRing { /* private fields */ }Expand description
Bounded ring mapping recent wire IDs to message handles within one stream epoch. When an ID is reused or evicted, the old mapping retires.
Implementations
Sourceimpl RefRing
impl RefRing
pub fn clear(&mut self)
Sourcepub fn record(&mut self, id: u8, handle: MessageHandle)
pub fn record(&mut self, id: u8, handle: MessageHandle)
Record id -> handle, retiring any previous mapping of id and the
oldest entry when full.
pub fn lookup(&self, id: u8) -> Option<MessageHandle>
pub fn lookup_handle(&self, handle: MessageHandle) -> Option<u8>